import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.ShellAdapter;
import org.eclipse.swt.events.ShellEvent;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

/**
 * Diese Klasse repräsentiert die Anmelde-GUI.
 * 
 * @author Jan Schwarzer
 *
 */
public class ClientSignInGUI {
	// Der Wave Client
	public Client waveClient = null;

	// Die Wave Client GUI
	public ClientGUI clientgui = null;

	// Der GUI-Rahmen
	public Display displaySignInGUI = new Display();
	public Shell shellSignInGUI = new Shell(displaySignInGUI);

	// Labels für den Login
	public Label labelServer = new Label(shellSignInGUI, SWT.NONE);
	public Label labelServerPort = new Label(shellSignInGUI, SWT.NONE);
	public Label labelUserName = new Label(shellSignInGUI, SWT.NONE);
	public Label labelError = new Label(shellSignInGUI, SWT.NONE);

	// Textfelder zur Eingabe
	public Text textServer = new Text(shellSignInGUI, SWT.NONE);
	public Text textServerPort = new Text(shellSignInGUI, SWT.NONE);
	public Text textUserName = new Text(shellSignInGUI, SWT.NONE);

	// Anmelde- bzw. Abbrechenbutton
	public Button buttonSignIn = new Button(shellSignInGUI, SWT.PUSH);
	public Button buttonAbort = new Button(shellSignInGUI, SWT.PUSH);

	// Farbe für Fehlermeldungstextfeld
	Color colorError = null;
	
	// Name des Servers + "@"-Zeichen für die Anmeldung der Benutzer
	public String domainName = "@googlewaveserver";

	public ClientSignInGUI() {
		shellSignInGUI.setText("Google Wave Login");
		shellSignInGUI.setSize(480, 195);
		shellSignInGUI.addShellListener(new ShellAdapter() {
			public void shellClosed(ShellEvent e) {
				System.exit(0);
			}
		});

		labelServer.setText("Server:");
		labelServer.setSize(100, 20);
		labelServer.setLocation(10, 10);

		labelServerPort.setText("Port:");
		labelServerPort.setSize(100, 20);
		labelServerPort.setLocation(10, 40);

		labelUserName.setText("Benutzername:");
		labelUserName.setSize(100, 20);
		labelUserName.setLocation(10, 70);

		labelError.setSize(450, 20);
		labelError.setLocation(10, 100);

		textServer.setText("localhost");
		textServer.setBounds(160, 10, 300, 20);
		textServer.setTextLimit(100);

		textServerPort.setText("9876");
		textServerPort.setBounds(160, 40, 300, 20);
		textServerPort.setTextLimit(100);

		textUserName.setText("jan");
		textUserName.setBounds(160, 70, 300, 20);
		textUserName.setTextLimit(100);

		buttonSignIn.setLocation(10, 135);
		buttonSignIn.setSize(100, 25);
		buttonSignIn.setText("Anmelden");
		buttonSignIn.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				try {
					waveClient = new Client();
					waveClient.connectToBackend(textUserName.getText() + domainName, textServer.getText(), textServerPort.getText());
					
					// Leider muss ein Delay eingearbeitet werden, da ansonsten nicht alle Wave-Informationen im Backend vorliegen
					try {
						Thread.sleep(100);
					} catch (InterruptedException e1) {
						e1.printStackTrace();
					}
					
					// Starten der GUI, alle Daten liegen jetzt vor
					clientgui = new ClientGUI(waveClient, displaySignInGUI, domainName);

					// Erfolgsmeldung über Anmeldung ausgeben
					labelError.setText("Erfolgreich verbunden!");
					colorError = displaySignInGUI.getSystemColor(SWT.COLOR_GREEN);
					labelError.setBackground(colorError);
				} catch (ServerConnectException exc) {
					labelError.setText(exc.getServerConnectException());
					colorError = displaySignInGUI.getSystemColor(SWT.COLOR_YELLOW);
					labelError.setBackground(colorError);
				}
			}
		});

		buttonAbort.setLocation(120, 135);
		buttonAbort.setSize(100, 25);
		buttonAbort.setText("Schließen");
		buttonAbort.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				System.exit(0);
			}
		});

		shellSignInGUI.open();
		
		while (!shellSignInGUI.isDisposed()) {
			if (!displaySignInGUI.readAndDispatch())
				displaySignInGUI.sleep();
		}
		displaySignInGUI.dispose();
	}

	public static void main(String[] args) {
		ClientSignInGUI cg = new ClientSignInGUI();
	}

}
